@@ -23,10 +23,10 @@ import angular from 'angular';
 import { uiModules } from 'ui/modules';
 import chrome from 'ui/chrome';
 import { wrapInI18nContext } from 'ui/i18n';
-import { applyTheme } from 'ui/theme';
 import { toastNotifications } from 'ui/notify';
 
-import 'ui/query_bar';
+import 'ui/search_bar';
+import 'ui/apply_filters';
 
 import { panelActionsStore } from './store/panel_actions_store';
 
@@ -55,7 +55,6 @@ import { ContextMenuActionsRegistryProvider } from 'ui/embeddable';
 import { VisTypesRegistryProvider } from 'ui/registry/vis_types';
 import { timefilter } from 'ui/timefilter';
 import { getUnhashableStatesProvider } from 'ui/state_management/state_hashing';
-import { documentationLinks } from 'ui/documentation_links';
 
 import { DashboardViewportProvider } from './viewport/dashboard_viewport_provider';
 
@@ -78,6 +77,7 @@ app.directive('dashboardApp', function ($injector) {
   const confirmModal = $injector.get('confirmModal');
   const config = $injector.get('config');
   const Private = $injector.get('Private');
+  const indexPatterns = $injector.get('indexPatterns');
 
   return {
     restrict: 'E',
@@ -87,14 +87,13 @@ app.directive('dashboardApp', function ($injector) {
       $rootScope,
       $route,
       $routeParams,
-      $window,
       getAppState,
       dashboardConfig,
       localStorage,
       i18n,
     ) {
       const filterManager = Private(FilterManagerProvider);
-      const filterBar = Private(FilterBarQueryFilterProvider);
+      const queryFilter = Private(FilterBarQueryFilterProvider);
       const docTitle = Private(DocTitleProvider);
       const embeddableFactories = Private(EmbeddableFactoriesRegistryProvider);
       const panelActionsRegistry = Private(ContextMenuActionsRegistryProvider);
@@ -126,7 +125,7 @@ app.directive('dashboardApp', function ($injector) {
       // The 'previouslyStored' check is so we only update the time filter on dashboard open, not during
       // normal cross app navigation.
       if (dashboardStateManager.getIsTimeSavedWithDashboard() && !getAppState.previouslyStored()) {
-        dashboardStateManager.syncTimefilterWithDashboard(timefilter, config.get('timepicker:quickRanges'));
+        dashboardStateManager.syncTimefilterWithDashboard(timefilter);
       }
 
       const updateState = () => {
@@ -134,12 +133,26 @@ app.directive('dashboardApp', function ($injector) {
         // https://github.com/angular/angular.js/wiki/Understanding-Scopes
         $scope.model = {
           query: dashboardStateManager.getQuery(),
+          filters: queryFilter.getFilters(),
           timeRestore: dashboardStateManager.getTimeRestore(),
           title: dashboardStateManager.getTitle(),
           description: dashboardStateManager.getDescription(),
+          timeRange: timefilter.getTime(),
+          refreshInterval: timefilter.getRefreshInterval(),
         };
         $scope.panels = dashboardStateManager.getPanels();
-        $scope.indexPatterns = dashboardStateManager.getPanelIndexPatterns();
+
+        const panelIndexPatterns = dashboardStateManager.getPanelIndexPatterns();
+        if (panelIndexPatterns && panelIndexPatterns.length > 0) {
+          $scope.indexPatterns = panelIndexPatterns;
+        }
+        else {
+          indexPatterns.getDefault().then((defaultIndexPattern) => {
+            $scope.$evalAsync(() => {
+              $scope.indexPatterns = [defaultIndexPattern];
+            });
+          });
+        }
       };
 
       // Part of the exposed plugin API - do not remove without careful consideration.
@@ -157,11 +170,11 @@ app.directive('dashboardApp', function ($injector) {
           query: '',
           language: localStorage.get('kibana.userQueryLanguage') || config.get('search:queryLanguage')
         },
-        filterBar.getFilters()
+        queryFilter.getFilters()
       );
 
-      timefilter.enableAutoRefreshSelector();
-      timefilter.enableTimeRangeSelector();
+      timefilter.disableTimeRangeSelector();
+      timefilter.disableAutoRefreshSelector();
 
       updateState();
 
@@ -195,7 +208,6 @@ app.directive('dashboardApp', function ($injector) {
       };
       updateBreadcrumbs();
       dashboardStateManager.registerChangeListener(updateBreadcrumbs);
-      config.watch('k7design', (val) => $scope.showPluginBreadcrumbs = !val);
 
       $scope.newDashboard = () => { kbnUrl.change(DashboardConstants.CREATE_NEW_DASHBOARD_URL, {}); };
       $scope.saveState = () => dashboardStateManager.saveState();
@@ -219,7 +231,9 @@ app.directive('dashboardApp', function ($injector) {
             dashboardStateManager.getPanels().find((panel) => panel.panelIndex === panelIndex);
       };
 
-      $scope.updateQueryAndFetch = function ({ query }) {
+      $scope.updateQueryAndFetch = function ({ query, dateRange }) {
+        timefilter.setTime(dateRange);
+
         const oldQuery = $scope.model.query;
         if (_.isEqual(oldQuery, query)) {
           // The user can still request a reload in the query bar, even if the
@@ -228,12 +242,37 @@ app.directive('dashboardApp', function ($injector) {
           dashboardStateManager.requestReload();
         } else {
           $scope.model.query = query;
-          dashboardStateManager.applyFilters($scope.model.query, filterBar.getFilters());
+          dashboardStateManager.applyFilters($scope.model.query, $scope.model.filters);
         }
         $scope.refresh();
       };
 
-      updateTheme();
+      $scope.onRefreshChange = function ({ isPaused, refreshInterval }) {
+        timefilter.setRefreshInterval({
+          pause: isPaused,
+          value: refreshInterval ? refreshInterval : $scope.model.refreshInterval.value
+        });
+      };
+
+      $scope.onFiltersUpdated = filters => {
+        // The filters will automatically be set when the queryFilter emits an update event (see below)
+        queryFilter.setFilters(filters);
+      };
+
+      $scope.onCancelApplyFilters = () => {
+        $scope.appState.$newFilters = [];
+      };
+
+      $scope.onApplyFilters = filters => {
+        queryFilter.addFiltersAndChangeTimeFilter(filters);
+        $scope.appState.$newFilters = [];
+      };
+
+      $scope.$watch('appState.$newFilters', (filters = []) => {
+        if (filters.length === 1) {
+          $scope.onApplyFilters(filters);
+        }
+      });
 
       $scope.indexPatterns = [];
 
@@ -253,6 +292,8 @@ app.directive('dashboardApp', function ($injector) {
         // directly passed down time filter. Then we can get rid of this reliance on scope broadcasts.
         $scope.refresh();
       });
+      $scope.$listenAndDigestAsync(timefilter, 'refreshIntervalUpdate', updateState);
+      $scope.$listenAndDigestAsync(timefilter, 'timeUpdate', updateState);
 
       function updateViewMode(newMode) {
         $scope.topNavMenu = getTopNavConfig(newMode, navActions, dashboardConfig.getHideWriteControls()); // eslint-disable-line no-use-before-define
@@ -280,7 +321,7 @@ app.directive('dashboardApp', function ($injector) {
           // it does on 'open' because it's been saved to the url and the getAppState.previouslyStored() check on
           // reload will cause it not to sync.
           if (dashboardStateManager.getIsTimeSavedWithDashboard()) {
-            dashboardStateManager.syncTimefilterWithDashboard(timefilter, config.get('timepicker:quickRanges'));
+            dashboardStateManager.syncTimefilterWithDashboard(timefilter);
           }
         }
 
@@ -356,7 +397,7 @@ app.directive('dashboardApp', function ($injector) {
           });
       }
 
-      $scope.showFilterBar = () => filterBar.getFilters().length > 0 || !dashboardStateManager.getFullScreenMode();
+      $scope.showFilterBar = () => $scope.model.filters.length > 0 || !dashboardStateManager.getFullScreenMode();
 
       $scope.showAddPanel = () => {
         dashboardStateManager.setFullScreenMode(false);
@@ -367,7 +408,6 @@ app.directive('dashboardApp', function ($injector) {
         $scope.kbnTopNav.click('edit');
       };
       const navActions = {};
-      navActions[TopNavIds.DOCUMENTATION] = () => $window.open(documentationLinks.kibana.dashboard);
       navActions[TopNavIds.FULL_SCREEN] = () =>
         dashboardStateManager.setFullScreenMode(true);
       navActions[TopNavIds.EXIT_EDIT_MODE] = () => onChangeViewMode(DashboardViewMode.VIEW);
@@ -440,11 +480,6 @@ app.directive('dashboardApp', function ($injector) {
       navActions[TopNavIds.OPTIONS] = (menuItem, navController, anchorElement) => {
         showOptionsPopover({
           anchorElement,
-          darkTheme: dashboardStateManager.getDarkTheme(),
-          onDarkThemeChange: (isChecked) => {
-            dashboardStateManager.setDarkTheme(isChecked);
-            updateTheme();
-          },
           useMargins: dashboardStateManager.getUseMargins(),
           onUseMarginsChange: (isChecked) => {
             dashboardStateManager.setUseMargins(isChecked);
@@ -473,36 +508,18 @@ app.directive('dashboardApp', function ($injector) {
       updateViewMode(dashboardStateManager.getViewMode());
 
       // update root source when filters update
-      $scope.$listen(filterBar, 'update', function () {
-        dashboardStateManager.applyFilters($scope.model.query, filterBar.getFilters());
+      $scope.$listen(queryFilter, 'update', function () {
+        $scope.model.filters = queryFilter.getFilters();
+        dashboardStateManager.applyFilters($scope.model.query, $scope.model.filters);
       });
 
       // update data when filters fire fetch event
-      $scope.$listen(filterBar, 'fetch', $scope.refresh);
+      $scope.$listen(queryFilter, 'fetch', $scope.refresh);
 
       $scope.$on('$destroy', () => {
         dashboardStateManager.destroy();
-
-        // Remove dark theme to keep it from affecting the appearance of other apps.
-        setLightTheme();
       });
 
-      function updateTheme() {
-        dashboardStateManager.getDarkTheme() ? setDarkTheme() : setLightTheme();
-      }
-
-      function setDarkTheme() {
-        chrome.removeApplicationClass(['theme-light']);
-        chrome.addApplicationClass('theme-dark');
-        applyTheme('dark');
-      }
-
-      function setLightTheme() {
-        chrome.removeApplicationClass(['theme-dark']);
-        chrome.addApplicationClass('theme-light');
-        applyTheme('light');
-      }
-
       if ($route.current.params && $route.current.params[DashboardConstants.NEW_VISUALIZATION_ID_PARAM]) {
         dashboardStateManager.addNewPanel($route.current.params[DashboardConstants.NEW_VISUALIZATION_ID_PARAM], 'visualization');
 
