@@ -33,7 +33,7 @@ import 'ui/filters/moment';
 import 'ui/index_patterns';
 import 'ui/state_management/app_state';
 import { timefilter } from 'ui/timefilter';
-import 'ui/query_bar';
+import 'ui/search_bar';
 import { hasSearchStategyForIndexPattern, isDefaultTypeIndexPattern } from 'ui/courier';
 import { toastNotifications } from 'ui/notify';
 import { VisProvider } from 'ui/vis';
@@ -64,6 +64,8 @@ import { showOpenSearchPanel } from '../top_nav/show_open_search_panel';
 import { tabifyAggResponse } from 'ui/agg_response/tabify';
 import { showSaveModal } from 'ui/saved_objects/show_saved_object_save_modal';
 import { SavedObjectSaveModal } from 'ui/saved_objects/components/saved_object_save_modal';
+import { getRootBreadcrumbs, getSavedSearchBreadcrumbs } from '../breadcrumbs';
+import { buildVislibDimensions } from 'ui/visualize/loader/pipeline_helpers/build_pipeline';
 
 const app = uiModules.get('apps/discover', [
   'kibana/notify',
@@ -73,8 +75,14 @@ const app = uiModules.get('apps/discover', [
 ]);
 
 uiRoutes
-  .defaults(/discover/, {
-    requireDefaultIndex: true
+  .defaults(/^\/discover(\/|$)/, {
+    requireDefaultIndex: true,
+    k7Breadcrumbs: ($route, $injector) =>
+      $injector.invoke(
+        $route.current.params.id
+          ? getSavedSearchBreadcrumbs
+          : getRootBreadcrumbs
+      )
   })
   .when('/discover/:id?', {
     template: indexTemplate,
@@ -175,6 +183,9 @@ function discoverController(
     requests: new RequestAdapter()
   };
 
+  timefilter.disableTimeRangeSelector();
+  timefilter.disableAutoRefreshSelector();
+
   $scope.getDocLink = getDocLink;
   $scope.intervalOptions = intervalOptions;
   $scope.showInterval = false;
@@ -341,6 +352,24 @@ function discoverController(
 
   const $state = $scope.state = new AppState(getStateDefaults());
 
+  $scope.filters = queryFilter.getFilters();
+
+  $scope.onFiltersUpdated = filters => {
+    // The filters will automatically be set when the queryFilter emits an update event (see below)
+    queryFilter.setFilters(filters);
+  };
+
+  $scope.applyFilters = filters => {
+    queryFilter.addFiltersAndChangeTimeFilter(filters);
+    $scope.state.$newFilters = [];
+  };
+
+  $scope.$watch('state.$newFilters', (filters = []) => {
+    if (filters.length === 1) {
+      $scope.applyFilters(filters);
+    }
+  });
+
   const getFieldCounts = async () => {
     // the field counts aren't set until we have the data back,
     // so we wait for the fetch to be done before proceeding
@@ -465,6 +494,12 @@ function discoverController(
         $scope.$listen(timefilter, 'fetch', function () {
           $scope.fetch();
         });
+        $scope.$listen(timefilter, 'refreshIntervalUpdate', () => {
+          $scope.updateRefreshInterval();
+        });
+        $scope.$listen(timefilter, 'timeUpdate', () => {
+          $scope.updateTime();
+        });
 
         $scope.$watchCollection('state.sort', function (sort) {
           if (!sort) return;
@@ -478,6 +513,7 @@ function discoverController(
 
         // update data source when filters update
         $scope.$listen(queryFilter, 'update', function () {
+          $scope.filters = queryFilter.getFilters();
           return $scope.updateDataSource().then(function () {
             $state.save();
           });
@@ -491,13 +527,8 @@ function discoverController(
         // fetch data when filters fire fetch event
         $scope.$listen(queryFilter, 'fetch', $scope.fetch);
 
-        timefilter.enableAutoRefreshSelector();
         $scope.$watch('opts.timefield', function (timefield) {
-          if (!!timefield) {
-            timefilter.enableTimeRangeSelector();
-          } else {
-            timefilter.disableTimeRangeSelector();
-          }
+          $scope.enableTimeRangeSelector = !!timefield;
         });
 
         $scope.$watch('state.interval', function () {
@@ -636,7 +667,8 @@ function discoverController(
       .catch(notify.error);
   };
 
-  $scope.updateQueryAndFetch = function ({ query }) {
+  $scope.updateQueryAndFetch = function ({ query, dateRange }) {
+    timefilter.setTime(dateRange);
     $state.query = query;
     $scope.fetch();
   };
@@ -754,9 +786,18 @@ function discoverController(
         const tabifiedData = tabifyAggResponse($scope.vis.aggs, merged);
         $scope.searchSource.rawResponse = merged;
         Promise
-          .resolve(responseHandler(tabifiedData))
+          .resolve(buildVislibDimensions($scope.vis, { timeRange: $scope.timeRange, searchSource: $scope.searchSource }))
+          .then(resp => responseHandler(tabifiedData, resp))
           .then(resp => {
-            visualizeHandler.render(resp);
+            visualizeHandler.render({
+              as: 'visualization',
+              value: {
+                visType: $scope.vis.type.name,
+                visData: resp,
+                visConfig: $scope.vis.params,
+                params: {},
+              }
+            });
           });
       }
 
@@ -822,6 +863,18 @@ function discoverController(
       from: dateMath.parse(timefilter.getTime().from),
       to: dateMath.parse(timefilter.getTime().to, { roundUp: true })
     };
+    $scope.time = timefilter.getTime();
+  };
+
+  $scope.updateRefreshInterval = function () {
+    $scope.refreshInterval = timefilter.getRefreshInterval();
+  };
+
+  $scope.onRefreshChange = function ({ isPaused, refreshInterval }) {
+    timefilter.setRefreshInterval({
+      pause: isPaused,
+      value: refreshInterval ? refreshInterval : $scope.refreshInterval.value
+    });
   };
 
   $scope.resetQuery = function () {
